@@ -50,7 +50,7 @@ class Rethink_DBS(GeneralData):
                     f"Conectando {dbname}, {dbhost}, {dbport}, for station {self.station}"
                 )
                 gprint("=" * 30)
-                self.session = await self.r.connect(db=dbname,
+                self.session = await self.r.connect(db_name=dbname,
                                                     host=dbhost,
                                                     port=dbport,
                                                     **kwargs)
@@ -77,8 +77,9 @@ class Rethink_DBS(GeneralData):
             raise ex
         return self.session
 
-    def close(self):
-        self.session.close(noreply_wait=True)
+    async def close(self):
+        if self.session:
+            await self.session.close(noreply_wait=True)
         super().close()
 
     async def reconnect(self, wait=False):
@@ -258,14 +259,15 @@ class Rethink_DBS(GeneralData):
                     data, durability='soft',
                     return_changes=True).run(self.session)
                 return await task_coro
+        except asyncio.InvalidStateError as invalid_e:
+            raise invalid_e
         except asyncio.CancelledError as ce:
             task = asyncio.current_task()
-            if task:
-                result = task.result()
             self.logger.exception(
                 "Error de cancelación de tarea {result},{table_name}")
             bprint(
                 f"Se cancela tarea para {table_name}, {filter_opt}, {result}")
+            raise ce
         except Exception as ec:
             task = asyncio.current_task()
             if task:
@@ -380,7 +382,10 @@ class Rethink_DBS(GeneralData):
             task = asyncio.current_task()
             if task:
                 task.cancel()
-                result = task.result()
+                try:
+                    await task
+                except asyncio.CancelledError as can_error:
+                    raise can_error
             self.logger.exception("Error de cancelación de tarea {result}")
             bprint(
                 f"Se cancela tarea para {table_name}, {filter_opt}, {result}")
@@ -389,7 +394,10 @@ class Rethink_DBS(GeneralData):
             task = asyncio.current_task()
             if task:
                 task.cancel()
-                result = task.result()
+                try:
+                    await task
+                except asyncio.CancelledError as can_error:
+                    raise can_error
             self.logger.exception("Error de cancelación de tarea {result}")
             bprint(
                 f"Se cancela tarea para {table_name}, {filter_opt}, {result}")
@@ -398,7 +406,10 @@ class Rethink_DBS(GeneralData):
             task = asyncio.current_task()
             if task:
                 task.cancel()
-                result = task.result()
+                try:
+                    await task
+                except asyncio.CancelledError as can_error:
+                    raise can_error
             bprint(
                 f"Se cancela tarea para {table_name}, {filter_opt}, result {result}"
             )
